@@ -1,5 +1,4 @@
 from django import forms
-from edc_action_item.forms import ActionItemFormMixin
 from edc_form_validators import FormValidatorMixin
 from edc_sites.forms import SiteModelFormMixin
 
@@ -8,14 +7,14 @@ from ...form_validators import DeathReportTmgFormValidator
 
 class DeathReportTmgModelFormMixin(
     SiteModelFormMixin,
-    ActionItemFormMixin,
     FormValidatorMixin,
 ):
 
     form_validator_cls = DeathReportTmgFormValidator
 
-    subject_identifier = forms.CharField(
-        label="Subject identifier",
-        required=False,
-        widget=forms.TextInput(attrs={"readonly": "readonly"}),
-    )
+    class Meta:
+        help_text = {"subject_identifier": "(read-only)", "action_identifier": "(read-only)"}
+        widgets = {
+            "subject_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
+            "action_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
+        }
