@@ -4,10 +4,7 @@ from edc_action_item.managers import (
     ActionIdentifierSiteManager,
 )
 from edc_action_item.models import ActionModelMixin
-from edc_identifier.model_mixins import (
-    NonUniqueSubjectIdentifierFieldMixin,
-    TrackingModelMixin,
-)
+from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_sites.models import SiteModelMixin
 
 from ...constants import AE_FOLLOWUP_ACTION
@@ -21,14 +18,11 @@ class AeFollowupModelMixin(
     AeFollowupMethodsModelMixin,
     SiteModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     models.Model,
 ):
 
     action_name = AE_FOLLOWUP_ACTION
 
-    tracking_identifier_prefix = "AF"
-
     on_site = ActionIdentifierSiteManager()
 
     objects = ActionIdentifierManager()
