@@ -17,7 +17,7 @@ class AeSusarMethodsModelMixin(models.Model):
         super().save(*args, **kwargs)
 
     def natural_key(self):
-        return (self.action_identifier,)
+        return (self.action_identifier,)  # noqa
 
     class Meta:
         abstract = True
