@@ -4,10 +4,7 @@ from edc_action_item.managers import (
     ActionIdentifierSiteManager,
 )
 from edc_action_item.models import ActionModelMixin
-from edc_identifier.model_mixins import (
-    NonUniqueSubjectIdentifierFieldMixin,
-    TrackingModelMixin,
-)
+from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model.models import ReportStatusModelMixin
 from edc_search.model_mixins import SearchSlugModelMixin
 from edc_sites.models import SiteModelMixin
@@ -25,14 +22,11 @@ class AeTmgModelMixin(
     SearchSlugModelMixin,
     SiteModelMixin,
     ActionModelMixin,
-    TrackingModelMixin,
     models.Model,
 ):
 
     action_name = AE_TMG_ACTION
 
-    tracking_identifier_prefix = "AT"
-
     on_site = ActionIdentifierSiteManager()
 
     objects = ActionIdentifierManager()
