@@ -9,6 +9,6 @@ from ...forms import AeFollowupModelFormMixin
 class TestModelformMixins(TestCase):
     def test_(self):
         class AeFollowupForm(AeFollowupModelFormMixin, forms.ModelForm):
-            class Meta:
+            class Meta(AeFollowupModelFormMixin.Meta):
                 model = AeFollowup
                 fields = "__all__"
